@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2011-2012 Raphaël Barrois
+# Copyright (c) 2011-2013 Raphaël Barrois
 
 import ConfigParser
 import logging
@@ -10,11 +10,13 @@ import socket
 import time
 import sys
 
-from mpdlcd import lcdrunner
-from mpdlcd import mpdwrapper
-from mpdlcd import display_fields
-from mpdlcd import display_pattern
-from mpdlcd import utils
+from . import lcdrunner
+from . import mpdwrapper
+from . import display_fields
+from . import display_pattern
+from . import mpdhooks
+from . import utils
+from . import __version__
 
 # General
 DEFAULT_CONFIG_FILE = '/etc/mpdlcd.conf'
@@ -162,8 +164,11 @@ def _make_patterns(patterns):
         mpdlcd.display_pattern.ScreenPatternList: a list of patterns from the
             given entries.
     """
-    registry = display_fields.FieldRegistry()
-    pattern_list = display_pattern.ScreenPatternList(registry)
+    field_registry = display_fields.FieldRegistry()
+
+    pattern_list = display_pattern.ScreenPatternList(
+            field_registry=field_registry,
+    )
     for pattern in patterns:
         pattern_list.add(pattern.split('\n'))
     return pattern_list
@@ -221,7 +226,8 @@ def run_forever(lcdproc='', mpd='', lcdproc_screen=DEFAULT_LCD_SCREEN_NAME,
         patterns = DEFAULT_PATTERNS
     pattern_list = _make_patterns(patterns)
 
-    runner.setup_pattern(pattern_list)
+    mpd_hook_registry = mpdhooks.HookRegistry()
+    runner.setup_pattern(pattern_list, hook_registry=mpd_hook_registry)
 
     # Launch
     mpd_client.connect()
@@ -241,7 +247,7 @@ LOGLEVELS = {
 
 
 def _make_parser():
-    parser = optparse.OptionParser()
+    parser = optparse.OptionParser(version='%prog ' + __version__)
 
     # General options
     # ---------------
